Bugs should be filed on Launchpad, not GitHub:

   https://bugs.launchpad.net/synergy-service

Also check the developer documentation at:

   https://indigo-dc.gitbooks.io/synergy-doc/content/doc/developer.html
